@@ -1,14 +1,13 @@
-use std::path::Path;
-
 use crate::server::Errors;
 use serde::{
     Deserialize,
     Serialize,
 };
+use std::path::Path;
 mod local;
 pub use local::LocalFilesystem;
 
-#[derive(Serialize, Deserialize)]
+#[derive(Serialize, Deserialize, Debug)]
 pub enum FilesystemErrors {
     FilesystemNotFound,
     FileNotFound,
@@ -22,20 +21,26 @@ pub trait Filesystem {
     fn list_dir_by_path(&self, path: &str) -> Result<Vec<DirItemInfo>, Errors>;
 }
 
-#[derive(Serialize, Deserialize)]
+#[derive(Serialize, Deserialize, Debug)]
 pub struct DirItemInfo {
     path: String,
     name: String,
     is_file: bool,
 }
 
-#[derive(Serialize, Deserialize)]
+#[derive(Serialize, Deserialize, Debug)]
 pub enum FileFormat {
     Unknown,
     Binary,
     Text(String),
 }
 
+/// Returns the content format of the give file
+///
+/// # Arguments
+///
+/// * `path`   - The path of the file
+///
 pub fn get_format_from_path(path: &str) -> FileFormat {
     if let Some(ext) = Path::new(path).extension() {
         match ext.to_str().unwrap() {
@@ -47,7 +52,8 @@ pub fn get_format_from_path(path: &str) -> FileFormat {
     }
 }
 
-#[derive(Serialize, Deserialize)]
+/// Contains information about a file
+#[derive(Serialize, Deserialize, Debug)]
 pub struct FileInfo {
     content: String,
     format: FileFormat,
